@@ -2,17 +2,22 @@
 
 import os
 import logging
+from typing import Optional, AnyStr
+
 from . import utils
 
 
-def install(cwd=False):
+def install(cwd: bool = False, path: Optional[AnyStr] = None):
     """
     Appends the directory of the chromedriver binary file to PATH.
 
-    :param cwd: Flag indicating whether to download to current working directory
+    :param cwd: Flag indicating whether to download to current working directory. If the `cwd` is True, then path argument will be ignored.
+    :param path: Specify the path where the Chrome driver will be installed. If the `cwd` value is True, this value is ignored.
     :return: The file path of chromedriver
     """
-    chromedriver_filepath = utils.download_chromedriver(cwd)
+    if cwd:
+        path = os.getcwd()
+    chromedriver_filepath = utils.download_chromedriver(path)
     if not chromedriver_filepath:
         logging.debug('Can not download chromedriver.')
         return
